summaryrefslogtreecommitdiff
path: root/chickadee/render.scm
diff options
context:
space:
mode:
Diffstat (limited to 'chickadee/render.scm')
-rw-r--r--chickadee/render.scm10
1 files changed, 6 insertions, 4 deletions
diff --git a/chickadee/render.scm b/chickadee/render.scm
index 140ec66..5b95d1b 100644
--- a/chickadee/render.scm
+++ b/chickadee/render.scm
@@ -84,11 +84,13 @@
(define-syntax-rule (with-framebuffer framebuffer body ...)
(with (*current-framebuffer* framebuffer)
;; As a convenience, initialize the viewport as well so that
;; the user doesn't have to explicitly make a viewport unless
;; they actually want to do fancy viewport manipulations.
(with-viewport (framebuffer-viewport framebuffer)
- body ...)))
+ (with-projection (framebuffer-projection framebuffer)
+ body ...))))
(define-syntax-rule (with-blend-mode blend-mode body ...)
(with (*current-blend-mode* blend-mode) body ...))
@@ -84,11 +84,13 @@
(define-syntax-rule (with-framebuffer framebuffer body ...)
(with (*current-framebuffer* framebuffer)
- ;; As a convenience, initialize the viewport as well so that
- ;; the user doesn't have to explicitly make a viewport unless
- ;; they actually want to do fancy viewport manipulations.
+ ;; As a convenience, initialize the viewport and projection
+ ;; matrix as well so that the user doesn't have to explicitly
+ ;; make a viewport and/or projection matrix unless they
+ ;; actually want to do fancy viewport manipulations.
(with-viewport (framebuffer-viewport framebuffer)